dnl kernel.m4 -- Find the appropriate kernel module.
dnl $Id: kernel.m4,v 1.1 2003/05/30 23:34:00 eagle Exp $
dnl
dnl Defines the macro SIDENT_KERNEL_MODULE, which probes for the appropriate
dnl kernel module to use on the local system, links the appropriate kernel
dnl module into the build tree, and warns if no appropriate kernel module
dnl could be found.
dnl
dnl The kernel files we have are:
dnl
dnl     k_aix42.c k_aix432.c
dnl     k_bsd42.c
dnl     k_dummy.c
dnl     k_irix4.c k_irix5.c
dnl     k_linux.c
dnl     k_next_mach.c
dnl     k_osf4.c
dnl     k_sunos54.c k_sunos55.c k_sunos56.c k_sunos57.c k_sunos58.c
dnl
dnl Also defines NO_KVM if the system doesn't require the kvm library to read
dnl the required kernel information (such as on Linux).

AC_DEFUN([SIDENT_KERNEL_MODULE],
[AC_REQUIRE([AC_CANONICAL_HOST])
AC_MSG_CHECKING([for responder kernel module])

kernel=unknown

case "$host" in
alpha-dec-osf4*) kernel=k_osf4.c ;;
*-solaris2.5*) kernel=k_sunos55.c ;;	
*-solaris2.6*) kernel=k_sunos56.c ;;	
*-solaris2.7*) kernel=k_sunos57.c ;;
*-solaris2.8*) kernel=k_sunos58.c ;;

# Solaris 9 can use the Solaris 8 module.
*-solaris2.9*) kernel=k_sunos58.c ;;

# linux does not need kvm.
*linux*)
    kernel=k_linux.c
    AC_DEFINE(NO_KVM, 1, [Define if you don't need kvm (i.e. linux).])
    ;;

*nextstep3*) kernel=k_next_mach.c ;;

# AIX 4.2 works on AIX 4.1.
*-aix4.1*) kernel=k_aix42.c ;;
*-aix4.2*) kernel=k_aix42.c ;;

*-aix4.3.2*) kernel=k_aix432.c ;;

*-irix5* | *-irix6* ) kernel=k_irix5.c ;;

esac

if test "$kernel" = unknown ; then
    kernel=k_dummy.c
    AC_MSG_RESULT($kernel)
    AC_MSG_WARN([Could not locate a kernel file for $host])
    AC_MSG_WARN([Building with dummy module, which won't actually work])
else
    AC_MSG_RESULT($kernel)
fi

AC_LINK_FILES([responder/kernel/$kernel], [responder/kernel.c])
])
