/** @file
 * Low-level call to transmit a query to an ident server.
 *
 * @author Peter Eriksson <pen@lysator.liu.se>
 *
 * $Id: id_query.c,v 1.5 2003/05/31 00:09:15 eagle Exp $
 */

#include "config.h"

#include <errno.h>
#include <signal.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <sys/time.h>
#include <sys/types.h>
#include <sys/wait.h>
#include <unistd.h>

#ifdef HAVE_SYS_SELECT_H
# include <sys/select.h>
#endif

#include "sident.h" 

int
id_query(ident_t *id, int resp_port, int req_port, struct timeval *timeout,
         struct ident_auth_client_data *auth_data)
{
    RETSIGTYPE (*old_sig)(int);
    int res;
    char buf[IDENT_BUFFER_SIZE];
    fd_set ws;
    auth_data->requester_port = req_port ; 
    auth_data->responder_port = resp_port ; 
    auth_data->fd = id->fd ; 
    auth_data->timeout = timeout ; 

    if ( auth_data != NULL ) {
      char *start_data;

      start_data = (*auth_data->auth_struct->start)(auth_data);
      if (start_data == NULL) {
        errno = EINVAL;         /* Arbitrary */
        return -1;
      }
      sprintf(buf, "%d , %d : AUTHENTICATE : %s\r\n\0",resp_port,req_port,
              start_data);
    } else {  
      sprintf(buf, "%d , %d\r\n", resp_port, req_port);
    }
    
#ifdef DEBUG 
    printf("Sending.. \n%s",buf) ; 
#endif 
    if (timeout)
    {
	FD_ZERO(&ws);
	FD_SET(id->fd, &ws);

	if ((res = select(FD_SETSIZE, NULL, &ws, NULL, timeout)) < 0)
	    return -1;
	
	if (res == 0)
	{
	    errno = ETIMEDOUT;
	    return -1;
	}
    }

    old_sig = signal(SIGPIPE, SIG_IGN);
    
    res = write(id->fd, buf, strlen(buf));
    
    signal(SIGPIPE, old_sig);
    
    return res;
}

